@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: config_defaults_inc.php,v 1.283.2.1.2.1.2.1.2.2.2.7 2006/07/24 01:43:05 thraxisp Exp $
+	# $Id: config_defaults_inc.php,v 1.283.2.1.2.1.2.1.2.2.2.14 2007/04/01 08:09:32 vboctor Exp $
 	# --------------------------------------------------------
 
 
@@ -23,7 +23,7 @@
 	# In general a value of OFF means the feature is disabled and ON means the
 	# feature is enabled.  Any other cases will have an explanation.
 
-	# For more details see http://manual.mantisbt.org/
+	# For more details see http://www.mantisbt.org/manual/
 
 	################################
 	# Mantis Database Settings
@@ -41,6 +41,8 @@
 	$g_db_username			= 'root';
 	$g_db_password			= '';
 	$g_database_name		= 'bugtracker';
+
+	# Supported types: mysql for MySQL, mysqli for MySQL, pgsql for PostgreSQL, mssql for MS SQL Server, oci8 for Oracle.
 	$g_db_type			= 'mysql';
 
 	############################
@@ -101,7 +103,7 @@
 	$g_core_path			= $g_absolute_path . 'core' . DIRECTORY_SEPARATOR;
 
 	# Used to link to manual for User Documentation.
-	$g_manual_url = 'http://manual.mantisbt.org/';
+	$g_manual_url = 'http://www.mantisbt.org/manual/';
 
 	#############################
 	# Web Server
@@ -312,7 +314,7 @@
 	#############################
 
 	# --- version variables -----------
-	$g_mantis_version		= '1.0.5';
+	$g_mantis_version		= '1.0.7';
 	$g_show_version			= ON;
 
 	################################
@@ -329,39 +331,48 @@
 	# list the choices that the users are allowed to choose
 	$g_language_choices_arr	= array(
 		'auto',
+		'bulgarian',
+		'catalan',
 		'chinese_simplified',
 		'chinese_simplified_utf8',
 		'chinese_traditional',
 		'chinese_traditional_utf8',
 		'croatian',
 		'czech',
+		'czech_utf8',
 		'danish',
 		'dutch',
 		'english',
 		'estonian',
 		'finnish',
 		'french',
+		'french_utf8',
 		'french_canadian',
 		'german',
 		'hungarian',
 		'icelandic',
 		'italian',
+		'italian_utf8',
 		'japanese_euc',
 		'japanese_sjis',
 		'japanese_utf8',
 		'korean',
+		'korean_utf8',
 		'latvian',
 		'lithuanian',
 		'norwegian',
 		'polish',
+		'polish_utf8',
 		'portuguese_brazil',
 		'portuguese_standard',
 		'romanian',
 		'russian',
 		'russian_koi8',
+		'russian_utf8',
 		'serbian',
 		'slovak',
 		'slovene',
+		'slovene_utf8',
 		'spanish',
 		'swedish',
 		'turkish',
@@ -370,33 +381,40 @@
 
 	# Browser language mapping for 'auto' language selection
 	$g_language_auto_map = array(
-		'en-us, en-gb, en-au, en' => 'english',
+		'bg' => 'bulgarian',
+		'ca' => 'catalan',
 		'zh-cn, zh-sg, zh' => 'chinese_simplified',
 		'zh-hk, zh-tw' => 'chinese_traditional',
 		'cs' => 'czech',
 		'da' => 'danish',
 		'nl-be, nl' => 'dutch',
+		'en-us, en-gb, en-au, en' => 'english',
 		'et' => 'estonian',
 		'fi' => 'finnish',
-		'fr-be, fr-ca, fr-ch, fr' => 'french',
+		'fr-be, fr-ch, fr' => 'french',
+		'fr-ca' => 'french_canadian',
 		'de-de, de-at, de-ch, de' => 'german',
 		'hu' => 'hungarian',
+		'hr' => 'croatian',
+		'is' => 'icelandic',
 		'it-ch, it' => 'italian',
-		'ja' => 'japanese_sjis',
+		'ja' => 'japanese_utf8',
 		'ko' => 'korean',
 		'lt' => 'lithuanian',
+		'lv' => 'latvian',
 		'no' => 'norwegian',
 		'pl' => 'polish',
 		'pt-br' => 'portugese_brazil',
 		'pt' => 'portugese_standard',
 		'ro-mo, ro' => 'romanian',
-		'ru-mo, ru' => 'russian',
+		'ru-mo, ru-ru, ru-ua, ru' => 'russian',
 		'sr' => 'serbian',
 		'sk' => 'slovak',
 		'sl' => 'slovene',
 		'es-mx, es-co, es-ar, es-cl, es-pr, es' => 'spanish',
 		'sv-fi, sv' => 'swedish',
-		'tr' => 'turkish'
+		'tr' => 'turkish',
+		'uk' => 'ukrainian'
 	);
 
 	# Fallback for automatic language selection
@@ -910,7 +928,7 @@
 
 	# access level needed to send a reminder from the bug view pages
 	# set to NOBODY to disable the feature
-	$g_bug_reminder_threshold		= REPORTER;
+	$g_bug_reminder_threshold		= DEVELOPER;
 
 	# access level needed to upload files to the project documentation section
 	# You can set this to NOBODY to prevent uploads to projects
